==> haskell-config-ini-0.2.6.0-49-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-config-ini.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 config-ini
version:              0.2.6.0
visibility:           public
id:                   config-ini-0.2.6.0-JkE4luuONWTEfRBJvwvvaV
key:                  config-ini-0.2.6.0-JkE4luuONWTEfRBJvwvvaV
license:              BSD-3-Clause
copyright:            ©2018 Getty Ritter
maintainer:           Getty Ritter <config-ini@infinitenegativeutility.com>
author:               Getty Ritter <config-ini@infinitenegativeutility.com>
homepage:             https://github.com/aisamanra/config-ini
synopsis:             A library for simple INI-based configuration files.
description:
    The @config-ini@ library is a set of small monadic languages
    for writing simple configuration languages with convenient,
    human-readable error messages.

    > parseConfig :: IniParser (Text, Int, Bool)
    > parseConfig = section "NETWORK" $ do
    >   user <- field        "user"
    >   port <- fieldOf      "port" number
    >   enc  <- fieldFlagDef "encryption" True
    >   return (user, port, enc)

category:             Configuration
abi:                  90eb09bdcf3c8c5e0aea126661b962bb
exposed:              True
exposed-modules:
    Data.Ini.Config Data.Ini.Config.Bidir Data.Ini.Config.Raw

import-dirs:          /usr/lib/ghc-9.2.8/site-local/config-ini-0.2.6.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/config-ini-0.2.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-config-ini
hs-libraries:         HSconfig-ini-0.2.6.0-JkE4luuONWTEfRBJvwvvaV
depends:
    base-4.16.4.0 containers-0.6.5.1
    megaparsec-9.6.1-DogeohYuFD2LN6njX3s3p6 text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.20-4Y4A6Wn35BzvWquDAxs4Y

haddock-interfaces:   /usr/share/doc/haskell-config-ini/html/config-ini.haddock
haddock-html:         /usr/share/doc/haskell-config-ini/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-config-ini-0.2.6.0-50-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-config-ini.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 config-ini
version:              0.2.6.0
visibility:           public
id:                   config-ini-0.2.6.0-7OOnefJ3OQXCBHRftozMoT
key:                  config-ini-0.2.6.0-7OOnefJ3OQXCBHRftozMoT
license:              BSD-3-Clause
copyright:            ©2018 Getty Ritter
maintainer:           Getty Ritter <config-ini@infinitenegativeutility.com>
author:               Getty Ritter <config-ini@infinitenegativeutility.com>
homepage:             https://github.com/aisamanra/config-ini
synopsis:             A library for simple INI-based configuration files.
description:
    The @config-ini@ library is a set of small monadic languages
    for writing simple configuration languages with convenient,
    human-readable error messages.

    > parseConfig :: IniParser (Text, Int, Bool)
    > parseConfig = section "NETWORK" $ do
    >   user <- field        "user"
    >   port <- fieldOf      "port" number
    >   enc  <- fieldFlagDef "encryption" True
    >   return (user, port, enc)

category:             Configuration
abi:                  7678c5e41d0917b1596a510ecd1e3c52
exposed:              True
exposed-modules:
    Data.Ini.Config Data.Ini.Config.Bidir Data.Ini.Config.Raw

import-dirs:          /usr/lib/ghc-9.2.8/site-local/config-ini-0.2.6.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/config-ini-0.2.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-config-ini
hs-libraries:         HSconfig-ini-0.2.6.0-7OOnefJ3OQXCBHRftozMoT
depends:
    base-4.16.4.0 containers-0.6.5.1
    megaparsec-9.6.1-KWiqPX6JJMLKdiZGxbvQf text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.20-AzoOiKjV26Z32LkoSmNfI7

haddock-interfaces:   /usr/share/doc/haskell-config-ini/html/config-ini.haddock
haddock-html:         /usr/share/doc/haskell-config-ini/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
